MouseArea

Struct MouseArea 

pub struct MouseArea<'a, Message> {
Show 23 fields id: Id, content: Element<'a, Message>, on_auto_scroll: Option<Box<dyn OnAutoScroll<'a, Message>>>, on_drag: Option<Box<dyn OnDrag<'a, Message>>>, on_double_click: Option<Box<dyn OnMouseButton<'a, Message>>>, on_press: Option<Box<dyn OnMouseButton<'a, Message>>>, on_drag_end: Option<Box<dyn OnMouseButton<'a, Message>>>, on_release: Option<Box<dyn OnMouseButton<'a, Message>>>, on_resize: Option<Box<dyn OnResize<'a, Message>>>, on_right_press: Option<Box<dyn OnMouseButton<'a, Message>>>, on_right_press_no_capture: bool, on_right_press_window_position: bool, on_right_release: Option<Box<dyn OnMouseButton<'a, Message>>>, on_middle_press: Option<Box<dyn OnMouseButton<'a, Message>>>, on_middle_release: Option<Box<dyn OnMouseButton<'a, Message>>>, on_back_press: Option<Box<dyn OnMouseButton<'a, Message>>>, on_back_release: Option<Box<dyn OnMouseButton<'a, Message>>>, on_forward_press: Option<Box<dyn OnMouseButton<'a, Message>>>, on_forward_release: Option<Box<dyn OnMouseButton<'a, Message>>>, on_scroll: Option<Box<dyn OnScroll<'a, Message>>>, on_enter: Option<Box<dyn OnEnterExit<'a, Message>>>, on_exit: Option<Box<dyn OnEnterExit<'a, Message>>>, show_drag_rect: bool,
}
Emit messages on mouse events.

Fields

id: Idcontent: Element<'a, Message>on_auto_scroll: Option<Box<dyn OnAutoScroll<'a, Message>>>on_drag: Option<Box<dyn OnDrag<'a, Message>>>on_double_click: Option<Box<dyn OnMouseButton<'a, Message>>>on_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_drag_end: Option<Box<dyn OnMouseButton<'a, Message>>>on_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_resize: Option<Box<dyn OnResize<'a, Message>>>on_right_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_right_press_no_capture: boolon_right_press_window_position: boolon_right_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_middle_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_middle_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_back_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_back_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_forward_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_forward_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_scroll: Option<Box<dyn OnScroll<'a, Message>>>on_enter: Option<Box<dyn OnEnterExit<'a, Message>>>on_exit: Option<Box<dyn OnEnterExit<'a, Message>>>show_drag_rect: bool

Implementations

Source

impl<'a, Message> MouseArea<'a, Message>

pub fn on_auto_scroll(self, message: impl OnAutoScroll<'a, Message>) -> Self

The message to emit when auto scroll changes.

pub fn on_drag(self, message: impl OnDrag<'a, Message>) -> Self

The message to emit when a drag is initiated.

pub fn on_drag_end(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit when a drag ends.

pub fn on_double_click(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a double click.

pub fn on_press(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a left button press.

pub fn on_release(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a left button release.

pub fn on_resize(self, message: impl OnResize<'a, Message>) -> Self

The message to emit on resizing.

pub fn on_right_press(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a right button press.

pub fn on_right_press_no_capture(self) -> Self

on_right_press will not capture input

pub fn wayland_on_right_press_window_position(self) -> Self

Only on wayland, on_right_press will provide window position instead of widget relative

pub fn on_right_press_window_position(self) -> Self

on_right_press will provide window position instead of widget relative

pub fn on_right_release(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a right button release.

pub fn on_middle_press(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a middle button press.

pub fn on_middle_release(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a middle button release.

pub fn on_back_press(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a back button press.

pub fn on_back_release(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a back button release.

pub fn on_forward_press(self, message: impl OnMouseButton<'a, Message>) -> Self

The message to emit on a forward button press.

pub fn on_forward_release( self, message: impl OnMouseButton<'a, Message>, ) -> Self

The message to emit on a forward button release.

pub fn on_scroll(self, message: impl OnScroll<'a, Message>) -> Self

The message to emit on a scroll.

pub fn on_enter(self, message: impl OnEnterExit<'a, Message>) -> Self

The message to emit when a mouse enters the area.

pub fn on_exit(self, message: impl OnEnterExit<'a, Message>) -> Self

The message to emit when a mouse exits the area.

pub const fn show_drag_rect(self, show_drag_rect: bool) -> Self

pub fn with_id(self, id: Id) -> Self

Sets the widget’s unique identifier.

Source

impl<'a, Message> MouseArea<'a, Message>

pub fn new(content: impl Into<Element<'a, Message>>) -> Self

Creates a MouseArea with the given content.