pub struct MouseArea<'a, Message> {Show 23 fields
id: Id,
content: Element<'a, Message>,
on_auto_scroll: Option<Box<dyn OnAutoScroll<'a, Message>>>,
on_drag: Option<Box<dyn OnDrag<'a, Message>>>,
on_double_click: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_press: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_drag_end: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_release: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_resize: Option<Box<dyn OnResize<'a, Message>>>,
on_right_press: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_right_press_no_capture: bool,
on_right_press_window_position: bool,
on_right_release: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_middle_press: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_middle_release: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_back_press: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_back_release: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_forward_press: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_forward_release: Option<Box<dyn OnMouseButton<'a, Message>>>,
on_scroll: Option<Box<dyn OnScroll<'a, Message>>>,
on_enter: Option<Box<dyn OnEnterExit<'a, Message>>>,
on_exit: Option<Box<dyn OnEnterExit<'a, Message>>>,
show_drag_rect: bool,
}Expand description
Emit messages on mouse events.
Fields
id: Idcontent: Element<'a, Message>on_auto_scroll: Option<Box<dyn OnAutoScroll<'a, Message>>>on_drag: Option<Box<dyn OnDrag<'a, Message>>>on_double_click: Option<Box<dyn OnMouseButton<'a, Message>>>on_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_drag_end: Option<Box<dyn OnMouseButton<'a, Message>>>on_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_resize: Option<Box<dyn OnResize<'a, Message>>>on_right_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_right_press_no_capture: boolon_right_press_window_position: boolon_right_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_middle_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_middle_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_back_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_back_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_forward_press: Option<Box<dyn OnMouseButton<'a, Message>>>on_forward_release: Option<Box<dyn OnMouseButton<'a, Message>>>on_scroll: Option<Box<dyn OnScroll<'a, Message>>>on_enter: Option<Box<dyn OnEnterExit<'a, Message>>>on_exit: Option<Box<dyn OnEnterExit<'a, Message>>>show_drag_rect: boolImplementations
Sourceimpl<'a, Message> MouseArea<'a, Message>
impl<'a, Message> MouseArea<'a, Message>
Sourcepub fn on_auto_scroll(self, message: impl OnAutoScroll<'a, Message>) -> Self
pub fn on_auto_scroll(self, message: impl OnAutoScroll<'a, Message>) -> Self
The message to emit when auto scroll changes.
Sourcepub fn on_drag(self, message: impl OnDrag<'a, Message>) -> Self
pub fn on_drag(self, message: impl OnDrag<'a, Message>) -> Self
The message to emit when a drag is initiated.
Sourcepub fn on_drag_end(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_drag_end(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit when a drag ends.
Sourcepub fn on_double_click(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_double_click(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a double click.
Sourcepub fn on_press(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_press(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a left button press.
Sourcepub fn on_release(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_release(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a left button release.
Sourcepub fn on_resize(self, message: impl OnResize<'a, Message>) -> Self
pub fn on_resize(self, message: impl OnResize<'a, Message>) -> Self
The message to emit on resizing.
Sourcepub fn on_right_press(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_right_press(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a right button press.
Sourcepub fn on_right_press_no_capture(self) -> Self
pub fn on_right_press_no_capture(self) -> Self
on_right_press will not capture input
Sourcepub fn wayland_on_right_press_window_position(self) -> Self
pub fn wayland_on_right_press_window_position(self) -> Self
Only on wayland, on_right_press will provide window position instead of widget relative
Sourcepub fn on_right_press_window_position(self) -> Self
pub fn on_right_press_window_position(self) -> Self
on_right_press will provide window position instead of widget relative
Sourcepub fn on_right_release(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_right_release(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a right button release.
Sourcepub fn on_middle_press(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_middle_press(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a middle button press.
Sourcepub fn on_middle_release(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_middle_release(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a middle button release.
Sourcepub fn on_back_press(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_back_press(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a back button press.
Sourcepub fn on_back_release(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_back_release(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a back button release.
Sourcepub fn on_forward_press(self, message: impl OnMouseButton<'a, Message>) -> Self
pub fn on_forward_press(self, message: impl OnMouseButton<'a, Message>) -> Self
The message to emit on a forward button press.
Sourcepub fn on_forward_release(
self,
message: impl OnMouseButton<'a, Message>,
) -> Self
pub fn on_forward_release( self, message: impl OnMouseButton<'a, Message>, ) -> Self
The message to emit on a forward button release.
Sourcepub fn on_scroll(self, message: impl OnScroll<'a, Message>) -> Self
pub fn on_scroll(self, message: impl OnScroll<'a, Message>) -> Self
The message to emit on a scroll.
Sourcepub fn on_enter(self, message: impl OnEnterExit<'a, Message>) -> Self
pub fn on_enter(self, message: impl OnEnterExit<'a, Message>) -> Self
The message to emit when a mouse enters the area.
Sourcepub fn on_exit(self, message: impl OnEnterExit<'a, Message>) -> Self
pub fn on_exit(self, message: impl OnEnterExit<'a, Message>) -> Self
The message to emit when a mouse exits the area.
pub const fn show_drag_rect(self, show_drag_rect: bool) -> Self